@@ -135,24 +135,15 @@ test_that("cded works with aoi with a different projection as mapsheets_250K", {
 })
 
 
-if (require("raster") && require("stars")) {
+if (require("stars")) {
   skip_on_cran()
   skip_if_offline()
 
   pol1 <- mapsheets_50K()[1,]
-  r <- raster(mapsheets_50K()[1,])
-  s <- st_as_stars(r)
+  s <- st_as_stars(pol1)
   bound_box <- st_bbox(s)
 
-  test_that("cded_raster accepts all inputs", {
-    expect_is(cded_raster(r), "RasterLayer")
-    expect_is(cded_raster(s), "RasterLayer")
-    expect_is(cded_raster(pol1), "RasterLayer")
-    expect_is(cded_raster(bound_box), "RasterLayer")
-  })
-
   test_that("cded_stars accepts all inputs", {
-    expect_is(cded_stars(r), "stars")
     expect_is(cded_stars(s), "stars")
     expect_is(cded_stars(pol1), "stars")
     expect_is(cded_stars(bound_box), "stars")
@@ -160,3 +151,18 @@ if (require("raster") && require("stars")) {
 
 }
 
+if (require("terra")) {
+  skip_on_cran()
+  skip_if_offline()
+
+  pol1 <- mapsheets_50K()[1,]
+  r <- rast(pol1)
+  bound_box <- st_bbox(pol1)
+
+  test_that("cded_terra accepts all inputs", {
+    expect_is(cded_terra(r), "SpatRaster")
+    expect_is(cded_terra(pol1), "SpatRaster")
+    expect_is(cded_terra(bound_box), "SpatRaster")
+  })
+}
+
